@@ -82,6 +82,10 @@ func (b *backend) pathStaticCredsRead(ctx context.Context, req *logical.Request,
 		return nil, fmt.Errorf("failed to decode credentials: %w", err)
 	}
 
+	b.TryRecordObservationWithRequest(ctx, req, ObservationTypeAWSStaticCredentialRead, map[string]interface{}{
+		"role_name": roleName.(string),
+	})
+
 	return &logical.Response{
 		Data: structs.New(credentials).Map(),
 	}, nil
