@@ -6,14 +6,11 @@
 package issuing
 
 import (
-	"context"
-
 	ctx509 "github.com/google/certificate-transparency-go/x509"
-	"github.com/hashicorp/vault/sdk/logical"
 )
 
 //go:generate go run github.com/hashicorp/vault/tools/stubmaker
 
-func entSetCertVerifyOptions(ctx context.Context, storage logical.Storage, issuerId IssuerID, options *ctx509.VerifyOptions) error {
+func entSetCertVerifyOptions(issuer *IssuerEntry, options *ctx509.VerifyOptions) error {
 	return nil
 }
