@@ -10,6 +10,7 @@ import (
 	"crypto/x509"
 	"fmt"
 	"net"
+	"strings"
 
 	"github.com/hashicorp/vault/sdk/helper/certutil"
 	"github.com/hashicorp/vault/sdk/helper/errutil"
@@ -253,12 +254,12 @@ func SignCert(b logical.SystemView, role *RoleEntry, entityInfo EntityInfo, caSi
 		return nil, nil, errutil.InternalError{Err: fmt.Sprintf("unsupported key type Value: %s", role.KeyType)}
 	}
 
-	// Before validating key lengths, update our KeyBits/SignatureBits based
+	// Before validating key lengths, update our KeyBits based
 	// on the actual CSR key type.
 	if role.KeyType == "any" {
-		// We update the Value of KeyBits and SignatureBits here (from the
+		// We update the Value of KeyBits here (from the
 		// role), using the specified key type. This allows us to convert
-		// the default Value (0) for SignatureBits and KeyBits to a
+		// the default Value (0) for KeyBits to a
 		// meaningful Value.
 		//
 		// We ignore the role's original KeyBits Value if the KeyType is any
@@ -268,8 +269,8 @@ func SignCert(b logical.SystemView, role *RoleEntry, entityInfo EntityInfo, caSi
 		// docs saying when key_type=any, we only enforce our specified minimums
 		// for signing operations
 		var err error
-		if role.KeyBits, role.SignatureBits, err = certutil.ValidateDefaultOrValueKeyTypeSignatureLength(
-			actualKeyType, 0, role.SignatureBits); err != nil {
+		if role.KeyBits, err = certutil.ValidateDefaultOrValueKeyType(
+			actualKeyType, 0); err != nil {
 			return nil, nil, errutil.InternalError{Err: fmt.Sprintf("unknown internal error updating default values: %v", err)}
 		}
 
@@ -282,6 +283,14 @@ func SignCert(b logical.SystemView, role *RoleEntry, entityInfo EntityInfo, caSi
 		}
 	}
 
+	// We fetch the key type from the certificate because the caSign.KeyType might be ManagedKeyType which isn't an
+	// algorithm, this is awkward because of upper-lower case differences
+	underlayingCaKeyType := strings.ToLower(caSign.Certificate.PublicKeyAlgorithm.String())
+	role.SignatureBits, err = certutil.ValidateDefaultOrValueHashBits(underlayingCaKeyType, role.SignatureBits)
+	if err != nil {
+		return nil, nil, errutil.InternalError{Err: fmt.Sprintf("unknown internal error updating default signature length value: %v", err)}
+	}
+
 	// At this point, role.KeyBits and role.SignatureBits should both
 	// be non-zero, for RSA and ECDSA keys. Validate the actualKeyBits based on
 	// the role's values. If the KeyType was any, and KeyBits was set to 0,
