@@ -410,7 +410,7 @@ func (b *backend) pathIssueSignCert(ctx context.Context, req *logical.Request, d
 
 	var caErr error
 	sc := b.makeStorageContext(ctx, req.Storage)
-	signingBundle, caErr := sc.fetchCAInfo(issuerName, issuing.IssuanceUsage)
+	signingBundle, issuer, caErr := sc.fetchCAInfoWithIssuer(issuerName, issuing.IssuanceUsage)
 	if caErr != nil {
 		switch caErr.(type) {
 		case errutil.UserError:
@@ -421,14 +421,10 @@ func (b *backend) pathIssueSignCert(ctx context.Context, req *logical.Request, d
 				"error fetching CA certificate: %s", caErr)}
 		}
 	}
-	issuerId, err := issuing.ResolveIssuerReference(ctx, req.Storage, role.Issuer)
-	if err != nil {
-		if issuerId == issuing.IssuerRefNotFound {
-			b.Logger().Warn("could not resolve issuer reference, may be using a legacy CA bundle")
-		} else {
-			return nil, err
-		}
+	if issuer.ID == issuing.LegacyBundleShimID {
+		b.Logger().Warn("could not resolve issuer reference, using a legacy CA bundle")
 	}
+
 	input := &inputBundle{
 		req:     req,
 		apiData: data,
@@ -436,6 +432,7 @@ func (b *backend) pathIssueSignCert(ctx context.Context, req *logical.Request, d
 	}
 	var parsedBundle *certutil.ParsedCertBundle
 	var warnings []string
+	var err error
 	if useCSR {
 		parsedBundle, warnings, err = signCert(b.System(), input, signingBundle, false, useCSRValues)
 	} else {
@@ -462,7 +459,7 @@ func (b *backend) pathIssueSignCert(ctx context.Context, req *logical.Request, d
 		return nil, err
 	}
 
-	if err = issuing.VerifyCertificate(sc.GetContext(), sc.GetStorage(), issuerId, parsedBundle); err != nil {
+	if err = issuing.VerifyCertificate(issuer, parsedBundle); err != nil {
 		return nil, err
 	}
 
@@ -479,7 +476,7 @@ func (b *backend) pathIssueSignCert(ctx context.Context, req *logical.Request, d
 			// TODO: Should we clean up the original cert here?
 			return nil, err
 		}
-		err = storeCertMetadata(ctx, req.Storage, issuerId, role.Name, parsedBundle.Certificate, metadataBytes)
+		err = storeCertMetadata(ctx, req.Storage, issuer.ID, role.Name, parsedBundle.Certificate, metadataBytes)
 		if err != nil {
 			// TODO: Should we clean up the original cert here?
 			return nil, err
@@ -500,7 +497,7 @@ func (b *backend) pathIssueSignCert(ctx context.Context, req *logical.Request, d
 	resp = addWarnings(resp, warnings)
 
 	b.pkiObserver.RecordPKIObservation(ctx, req, observe.ObservationTypePKIIssue,
-		observe.NewAdditionalPKIMetadata("issuer_id", issuerId),
+		observe.NewAdditionalPKIMetadata("issuer_id", issuer.ID),
 		observe.NewAdditionalPKIMetadata("issuer_name", role.Issuer),
 		observe.NewAdditionalPKIMetadata("signed", useCSR),
 		observe.NewAdditionalPKIMetadata("role_name", role.Name),
