@@ -1102,9 +1102,11 @@ func validateRole(b *backend, entry *issuing.RoleEntry, ctx context.Context, s l
 		), nil
 	}
 
-	if entry.KeyBits, entry.SignatureBits, err = certutil.ValidateDefaultOrValueKeyTypeSignatureLength(entry.KeyType, entry.KeyBits, entry.SignatureBits); err != nil {
-		return logical.ErrorResponse(err.Error()), nil
+	keyBits, err := certutil.ValidateDefaultOrValueKeyType(entry.KeyType, entry.KeyBits)
+	if err != nil {
+		return nil, fmt.Errorf("error setting keyBits %v on role for keyType %v: %v", entry.KeyBits, entry.KeyType, err.Error())
 	}
+	entry.KeyBits = keyBits
 
 	if entry.SerialNumberSource != "" &&
 		entry.SerialNumberSource != "json-csr" &&
@@ -1132,13 +1134,15 @@ func validateRole(b *backend, entry *issuing.RoleEntry, ctx context.Context, s l
 	// resolve the reference (to an issuerId) at role creation time; instead,
 	// resolve it at use time. This allows values such as `default` or other
 	// user-assigned names to "float" and change over time.
-	if len(entry.Issuer) == 0 {
-		entry.Issuer = defaultRef
+	var issuerId issuing.IssuerID
+	issuer := entry.Issuer
+	if len(issuer) == 0 {
+		issuer = defaultRef
 	}
 	// Check that the issuers reference set resolves to something
 	if !b.UseLegacyBundleCaStorage() {
 		sc := b.makeStorageContext(ctx, s)
-		issuerId, err := sc.resolveIssuerReference(entry.Issuer)
+		issuerId, err = sc.resolveIssuerReference(issuer)
 		if err != nil {
 			if issuerId == issuing.IssuerRefNotFound {
 				resp = &logical.Response{}
@@ -1151,7 +1155,29 @@ func validateRole(b *backend, entry *issuing.RoleEntry, ctx context.Context, s l
 				return nil, err
 			}
 		}
+	}
 
+	// Validate SignatureBits Against Issuer, if there is one, this is just to set a warning, so don't error out here:
+	if issuerId != issuing.IssuerRefNotFound {
+		if b.UseLegacyBundleCaStorage() {
+			issuerId = issuing.LegacyBundleShimID
+		}
+		issuerEntry, _, err := issuing.FetchCertBundleByIssuerId(ctx, s, issuerId, false)
+		if err != nil {
+			resp.AddWarning(fmt.Sprintf("Failed to fetch entry for issuer %q to validate against: %v", entry.Issuer, err))
+		} else {
+			issuerCertificate, err := issuerEntry.GetCertificate()
+			if err != nil {
+				resp.AddWarning(fmt.Sprintf("Unable to get certificate for issuer %s to validate against: %v", entry.Issuer, err))
+			}
+			issuerKeyType := strings.ToLower(issuerCertificate.PublicKeyAlgorithm.String())
+			entry.SignatureBits, err = certutil.ValidateDefaultOrValueHashBits(issuerKeyType, entry.SignatureBits)
+			if err != nil {
+				resp.AddWarning(fmt.Sprintf("The Issuing Certificate %v for this role has a key algorithm, %v, incompatible with the set role signature bits, %v", entry.Issuer, issuerKeyType, entry.SignatureBits))
+			}
+		}
+	} else if entry.SignatureBits == 0 {
+		entry.SignatureBits = 256
 	}
 
 	// Ensures CNValidations are alright
