@@ -54,57 +54,57 @@ type creationBundle struct {
 	Extensions      map[string]string
 }
 
-func (b *backend) pathSignIssueCertificateHelper(ctx context.Context, req *logical.Request, data *framework.FieldData, role *sshRole, publicKey ssh.PublicKey) (*logical.Response, error) {
+func (b *backend) pathSignIssueCertificateHelper(ctx context.Context, req *logical.Request, data *framework.FieldData, role *sshRole, publicKey ssh.PublicKey) (*logical.Response, map[string]interface{}, error) {
 	// Note that these various functions always return "user errors" so we pass
 	// them as 4xx values
 	keyID, err := b.calculateKeyID(data, req, role, publicKey)
 	if err != nil {
-		return logical.ErrorResponse(err.Error()), nil
+		return logical.ErrorResponse(err.Error()), nil, nil
 	}
 
 	certificateType, err := b.calculateCertificateType(data, role)
 	if err != nil {
-		return logical.ErrorResponse(err.Error()), nil
+		return logical.ErrorResponse(err.Error()), nil, nil
 	}
 
 	var parsedPrincipals []string
 	if certificateType == ssh.HostCert {
 		parsedPrincipals, err = b.calculateValidPrincipals(data, req, role, "", role.AllowedDomains, role.AllowedDomainsTemplate, validateValidPrincipalForHosts(role))
 		if err != nil {
-			return logical.ErrorResponse(err.Error()), nil
+			return logical.ErrorResponse(err.Error()), nil, nil
 		}
 	} else {
 		defaultPrincipal := role.DefaultUser
 		if role.DefaultUserTemplate {
 			defaultPrincipal, err = b.renderPrincipal(role.DefaultUser, req)
 			if err != nil {
-				return nil, err
+				return nil, nil, err
 			}
 		}
 		parsedPrincipals, err = b.calculateValidPrincipals(data, req, role, defaultPrincipal, role.AllowedUsers, role.AllowedUsersTemplate, strutil.StrListContains)
 		if err != nil {
-			return logical.ErrorResponse(err.Error()), nil
+			return logical.ErrorResponse(err.Error()), nil, nil
 		}
 	}
 
 	ttl, err := b.calculateTTL(data, role)
 	if err != nil {
-		return logical.ErrorResponse(err.Error()), nil
+		return logical.ErrorResponse(err.Error()), nil, nil
 	}
 
 	criticalOptions, err := b.calculateCriticalOptions(data, role)
 	if err != nil {
-		return logical.ErrorResponse(err.Error()), nil
+		return logical.ErrorResponse(err.Error()), nil, nil
 	}
 
 	extensions, addExtTemplatingWarning, err := b.calculateExtensions(data, req, role)
 	if err != nil {
-		return logical.ErrorResponse(err.Error()), nil
+		return logical.ErrorResponse(err.Error()), nil, nil
 	}
 
 	signer, err := b.getCASigner(ctx, req.Storage)
 	if err != nil {
-		return nil, fmt.Errorf("error creating signer: %w", err)
+		return nil, nil, fmt.Errorf("error creating signer: %w", err)
 	}
 
 	cBundle := creationBundle{
@@ -121,12 +121,12 @@ func (b *backend) pathSignIssueCertificateHelper(ctx context.Context, req *logic
 
 	certificate, err := cBundle.sign()
 	if err != nil {
-		return nil, err
+		return nil, nil, err
 	}
 
 	signedSSHCertificate := ssh.MarshalAuthorizedKey(certificate)
 	if len(signedSSHCertificate) == 0 {
-		return nil, errors.New("error marshaling signed certificate")
+		return nil, nil, errors.New("error marshaling signed certificate")
 	}
 
 	response := &logical.Response{
@@ -140,7 +140,14 @@ func (b *backend) pathSignIssueCertificateHelper(ctx context.Context, req *logic
 		response.AddWarning("default_extension templating enabled with at least one extension requiring identity templating. However, this request lacked identity entity information, causing one or more extensions to be skipped from the generated certificate.")
 	}
 
-	return response, nil
+	metadata := map[string]interface{}{
+		"certificate_type": certificateType,
+		"ttl":              ttl.String(),
+		"serial_number":    strconv.FormatUint(certificate.Serial, 16),
+		"key_id":           keyID,
+	}
+
+	return response, metadata, nil
 }
 
 func (b *backend) renderPrincipal(principal string, req *logical.Request) (string, error) {
