@@ -5,6 +5,7 @@ package vault
 
 import (
 	"context"
+	"crypto/rand"
 	"fmt"
 	"time"
 
@@ -321,7 +322,11 @@ func (d dynamicSystemView) GeneratePasswordFromPolicy(ctx context.Context, polic
 		return "", fmt.Errorf("stored password policy is invalid: %w", err)
 	}
 
-	return passPolicy.Generate(ctx, nil)
+	rng, err := d.core.GetConfigurableRNG(policyCfg.EntropySource, rand.Reader)
+	if err != nil {
+		return "", fmt.Errorf("stored password policy is invalid: %w", err)
+	}
+	return passPolicy.Generate(ctx, rng)
 }
 
 func (d dynamicSystemView) ClusterID(ctx context.Context) (string, error) {
